Examples
========

These examples can be found in the ``<pytorch-spiking>/docs/examples`` directory
(where ``<pytorch-spiking>`` is the location of the PyTorchSpiking package).  The
examples are Jupyter notebooks; if you would like to run them yourself, refer to
the `Jupyter documentation <https://jupyter-notebook.readthedocs.io/en/latest/>`_.

.. toctree::

    examples/spiking-fashion-mnist
